Index: content/renderer/gpu/command_buffer_proxy.h |
diff --git a/content/renderer/gpu/command_buffer_proxy.h b/content/renderer/gpu/command_buffer_proxy.h |
index 7c9778e769961c016fa7cd7862cd015d6a95aacb..f154eda2e8df37948fd3c803c23cb5d29eb08fc5 100644 |
--- a/content/renderer/gpu/command_buffer_proxy.h |
+++ b/content/renderer/gpu/command_buffer_proxy.h |
@@ -19,6 +19,7 @@ |
#include "gpu/command_buffer/common/command_buffer.h" |
#include "ipc/ipc_channel.h" |
#include "ipc/ipc_message.h" |
+#include "ui/gfx/gl/gl_surface.h" |
class GpuChannelHost; |
struct GPUCommandBufferConsoleMessage; |
@@ -65,8 +66,8 @@ class CommandBufferProxy : public gpu::CommandBuffer, |
// the task whether the echo succeeds or not. |
bool Echo(const base::Closure& callback); |
- // Sends an IPC message with the new state of surface visibility |
- bool SetSurfaceVisible(bool visible); |
+ // Sends an IPC message with the new state of resource usage |
+ bool SetResourceUsage(gfx::GLSurface::ResourceUsage resourceUsage); |
// Reparent a command buffer. TODO(apatrick): going forward, the notion of |
// the parent / child relationship between command buffers is going away in |